Macro Africa Module
===================

The macro_africa module will provide African economic data connectors.

.. automodule:: actuneo.macro_africa
   :members:
   :undoc-members:
   :show-inheritance:

.. note::
   This module is under development. Contributions are welcome!

Planned Features
----------------

* Inflation data by country
* GDP statistics
* Currency exchange rates
* Interest rate benchmarks
* Economic indicators
* Data connectors to African central banks

